/****************************************************************
*
* Copyright (C) 2004 SignalQuest, Inc.
*
*----------------------------------------------------------------
* All software and related documentation is provided "AS IS" and 
* without warranty or support of any kind and SignalQuest 
* expressly disclaims all other warranties, express or implied, 
* including, but not limited to, the implied warranties of 
* merchantability and fitness for a particular purpose. Under no 
* circumstances shall SignalQuest be liable for any 
* incidental, special or consequential damages that result from 
* the use or inability to use the software or related 
* documentation, even if SignalQuest has been advised of 
* the liability.
*
* Unless otherwise stated, software written and copyrighted by 
* SignalQuest is distributed as "freeware". You may use 
* and modify this software without any charge or restriction. 
* You may distribute to others, as long as the original author 
* is acknowledged.
*
*****************************************************************
* 
* Project:  SignalQuest Serial Communications DLL 
*
* File:    DLLFuncs.cpp
* History:
*   Version 1.71 (2004-11-10) pmt. Extensive fixes to thread usage.
*   Version 1.5 (2004-08-30)
*
****************************************************************/


// DLLFuncs.cpp



// Standard Win32 / MFC Includes
#include "stdafx.h"							// Required for MFC projects

// SQ-defined includes
#include "SQIncl.h"						// CSQIncl10App header



// Global application object (see [SQIncl10.cpp] for definition)
extern CSQInclApp theApp;



extern "C" __declspec (dllexport) LONG SQConfig(
	LONG liMode,
	LONG liBuffSize,
	LONG liRS232Timeout,
	LONG * liRetVal1,
	LONG * liRetVal2)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;


	liErrorCode = theApp.Config(
		liMode,
		liBuffSize,
		liRS232Timeout,
		liRetVal1,
		liRetVal2);


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQOpenPort(
	LONG liCOMPort,
	LONG liBaudRate,
	LPSTR lpszParity,
	LONG liWordSize,
	LONG liStopBits,
	LONG liXonXoff,
	LONG liRtsCts,
	LONG liDtrDsr)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;


	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.OpenPort(
			szCOMPort,
			liBaudRate,
			lpszParity,
			liWordSize,
			liStopBits,
			liXonXoff,
			liRtsCts,
			liDtrDsr);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQClosePort(
	LONG liCOMPort)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.CloseCOMPort(szCOMPort);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQResetDevice(
	LONG liCOMPort)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.ResetDevice(szCOMPort);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQClearLatchedError(
	LONG liCOMPort)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.ClearLatchedError(szCOMPort);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQGetData2(
	LONG liCOMPort,
	FLOAT * pfValue1,
	FLOAT * pfValue2,
	LONG * pliPacketCount,
	LONG * pliPacketError,
	LONG * pliLatchedError,
	LONG * pliBytesInBuffer)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.GetData2(
			szCOMPort,
			pfValue1,
			pfValue2,
			pliPacketCount,
			pliPacketError,
			pliLatchedError,
			pliBytesInBuffer);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQFindFirstDevice(
	LONG liStartCOM,
	LONG liEndCOM,
	LONG liBaudRate,
	LPSTR lpszParity,
	LONG liWordSize,
	LONG liStopBits,
	LONG liXonXoff,
	LONG liRtsCts,
	LONG liDtrDsr)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		liErrorCode = theApp.FindFirstDevice(
			liStartCOM,
			liEndCOM,
			liBaudRate,
			lpszParity,
			liWordSize,
			liStopBits,
			liXonXoff,
			liRtsCts,
			liDtrDsr);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
} // End SQFindFirstDevice()




extern "C" __declspec (dllexport) LONG SQGetErrorString(
	LONG liErrorCode, 
	LONG liBuffSize,
	LPTSTR lptszBuffer)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	return(theApp.GetErrorString(liErrorCode, liBuffSize, lptszBuffer));
}




extern "C" __declspec (dllexport) LONG SQReadCTS(
	LONG liCOMPort,
	LONG * pliCTSStatus)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.GetCTSStatus(szCOMPort, pliCTSStatus);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQReadDSR(
	LONG liCOMPort,
	LONG * pliDSRStatus)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.GetDSRStatus(szCOMPort, pliDSRStatus);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQWriteRTS(
	LONG liCOMPort,
	LONG liRTSStatus)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.SetRTSStatus(szCOMPort, liRTSStatus);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}




extern "C" __declspec (dllexport) LONG SQWriteDTR(
	LONG liCOMPort,
	LONG liDTRStatus)
{
	// Required for MFC DLL's
	AFX_MANAGE_STATE(AfxGetStaticModuleState());


	LONG liErrorCode = 0;

	
	// Has DLL initialization function been called yet?
	if(theApp.GetPreloadedState() == 1)
	{
		char szCOMPort[10];


		sprintf(szCOMPort, "COM%d", liCOMPort);


		liErrorCode = theApp.SetDTRStatus(szCOMPort, liDTRStatus);
	}
	else
	{
		liErrorCode = ERROR_DLL_NOT_INITIALIZED;
	}


	return(liErrorCode);
}
