/****************************************************************
*
* Copyright (C) 2004 SignalQuest, Inc.
*
*----------------------------------------------------------------
* All software and related documentation is provided "AS IS" and 
* without warranty or support of any kind and SignalQuest 
* expressly disclaims all other warranties, express or implied, 
* including, but not limited to, the implied warranties of 
* merchantability and fitness for a particular purpose. Under no 
* circumstances shall SignalQuest be liable for any 
* incidental, special or consequential damages that result from 
* the use or inability to use the software or related 
* documentation, even if SignalQuest has been advised of 
* the liability.
*
* Unless otherwise stated, software written and copyrighted by 
* SignalQuest is distributed as "freeware". You may use 
* and modify this software without any charge or restriction. 
* You may distribute to others, as long as the original author 
* is acknowledged.
*
*****************************************************************
* 
* Project:  SignalQuest Serial Communications DLL
*
* File:    MyWin32Port.h
*
* History:
*   Version 1.71 (2004-11-10) pmt. Extensive fixes to thread usage.
*   Version 1.5  (2004-08-30)
*
****************************************************************/


// From Mark Nelson's Guide to Windows Serial Communications, Chapter 12 demo
// http://www.dogma.net/markn/serial2/serial2.htm
// Used with permission from author
// Modified to work with SignalQuest proprietary sensor technology interface


// MyWin32Port.h: interface for the MyWin32Port class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_MYWIN32PORT_H__C736F122_FDAA_11D2_BDEF_00207813663F__INCLUDED_)
#define AFX_MYWIN32PORT_H__C736F122_FDAA_11D2_BDEF_00207813663F__INCLUDED_

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000


#include "Win32Port.h"
#include "RS232Messages.h"


class MyWin32Port : public Win32Port  
{
public:
    MyWin32Port( HWND notify_window,
                 const string &port_name,
                 long baud_rate = UNCHANGED,
                 char parity = UNCHANGED,
                 int word_length = UNCHANGED,
                 int stop_bits = UNCHANGED,
                 int dtr = SET,
                 int rts = SET,
                 int xon_xoff = DISABLE,
                 int rts_cts = DISABLE,
                 int dtr_dsr = DISABLE ) : Win32Port( port_name,
                                                      baud_rate,
                                                      parity,
                                                      word_length,
                                                      stop_bits,
                                                      dtr,
                                                      rts,
                                                      xon_xoff,
                                                      rts_cts,
                                                      dtr_dsr ),
                                            m_hNotifyWindow(notify_window){}

    virtual ~MyWin32Port(){}

protected :
/* pmt see if the Win32Port declarations are being interfered with... 
*/
	void PacketNotify(WPARAM wParam, LPARAM lParam)
	{
		//::PostMessage(m_hNotifyWindow, WM_SQ_PACKET_READ, wParam, lParam);
	}


	void RxNotify(int byte_count)
	{
		//::PostMessage(m_hNotifyWindow, WM_SERIAL_RX_NOTIFY, byte_count, 0);
	}


	void ParityErrorNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_PARITY_ERROR_NOTIFY, 0, 0);
	}


	void FramingErrorNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_FRAMING_ERROR_NOTIFY, 0, 0);
	}


	void HardwareOverrunErrorNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_HARDWARE_OVERRUN_ERROR_NOTIFY, 0, 0);
	}


	void SoftwareOverrunErrorNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_SOFTWARE_OVERRUN_ERROR_NOTIFY, 0, 0);
	}


	void BreakDetectNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_BREAK_DETECT_NOTIFY, 0, 0);
	}


	void CtsNotify(bool status)
	{
		//::PostMessage(m_hNotifyWindow, WM_CTS_NOTIFY, status, 0);


		SetCTSStatus(status);
	}


	void DsrNotify(bool status)
	{
		//::PostMessage(m_hNotifyWindow, WM_DSR_NOTIFY, status, 0);


		SetDSRStatus(status);
	}


	void CdNotify(bool status)
	{
		//::PostMessage(m_hNotifyWindow, WM_CD_NOTIFY, status, 0);
	}


	void RiNotify(bool status)
	{
		//::PostMessage(m_hNotifyWindow, WM_RI_NOTIFY, status, 0);
	}


	void TxNotify()
	{
		//::PostMessage(m_hNotifyWindow, WM_TX_NOTIFY, 0, 0);
	}
/**/


	const HWND m_hNotifyWindow;
};


#endif // !defined(AFX_MYWIN32PORT_H__C736F122_FDAA_11D2_BDEF_00207813663F__INCLUDED_)
